| pEL | R Documentation |
Cumulative Distribution Function of the Extended Laplace Distribution
pEL(y, mu, sigma, delta)
y |
Vector of values where the density is to be evaluated |
mu |
Location parameter |
sigma |
Scale parameter (must be > 0) |
delta |
Uniform noise parameter (must be > 0) |
Vector of distribution values
Saah, D. K., & Kozubowski, T. J. (2025). A new class of extended Laplace distributions with applications to modeling contaminated Laplace data. Journal of Computational and Applied Mathematics. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.cam.2025.116588")}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.