| rEL | R Documentation |
Generates random samples from the Extended Laplace distribution using the convolution representation: Y = X + U, where X \sim \text{Laplace}(\mu, \sigma) and U \sim \text{Uniform}(-\delta, \delta).
rEL(n, mu, sigma, delta)
n |
Integer. Sample size. |
mu |
Numeric. Location parameter. |
sigma |
Numeric. Scale parameter (must be > 0). |
delta |
Numeric. Uniform noise parameter (must be > 0). |
A numeric vector of random samples from the Extended Laplace distribution.
Saah, D. K., & Kozubowski, T. J. (2025). A new class of extended Laplace distributions with applications to modeling contaminated Laplace data. Journal of Computational and Applied Mathematics. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.cam.2025.116588")}
rEL(10, mu = 0, sigma = 1, delta = 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.